import { ButtonHTMLAttributes, FC, useState } from "react";
import { OutlinedButton } from "@src/components/common/buttons/outlinedButton";
import Tippy from "@tippyjs/react";

interface AddPriorityButtonProps
  extends ButtonHTMLAttributes<HTMLButtonElement> {
  initialPriority?: string;
  onPriorityChanged: (project: string) => void;
}

export const AddPriorityButton: FC<AddPriorityButtonProps> = (props) => {
  const [menuIsOpen, setMenuIsOpen] = useState(false);
  return (
    <Tippy
      placement="bottom"
      visible={menuIsOpen}
      onClickOutside={() => {
        setMenuIsOpen(false);
      }}
      delay={0}
      interactive={true}
      duration={0}
      content={
        <div
          className="py-2 px-2 bg-white dark:bg-gray-700 border border-accent-500 rounded-md flex flex-col gap-4"
          tabIndex={0}
        >
          <div className="space-y-2">
            {["p1", "p2", "p3"].map((p) => (
              <div key={p}>
                <button
                  type="button"
                  className="whitespace-nowrap py-1 px-4 dark:text-white dark:bg-gray-500 rounded-sm"
                  onClick={() => props.onPriorityChanged(p)}
                >
                  {p}
                </button>
              </div>
            ))}
          </div>
        </div>
      }
    >
      <span>
        <OutlinedButton
          className="whitespace-nowrap"
          onClick={() => setMenuIsOpen(true)}
        >
          {props.children || "Add Priority"}
        </OutlinedButton>
      </span>
    </Tippy>
  );
};
